Define theme for awesome table plot.
ttheme_awesome(
base_size = 8,
base_colour = "black",
base_family = "",
core_size = 10,
scale_breaks = 10,
scale_ratio = 0.25,
color_palette = "black",
color_breaks = NULL,
rep_mode = "col",
parse = FALSE,
size_unit = "mm",
padding = c(0.3, 0.3),
show_legend = TRUE,
legend_position = NULL,
legend_layout = NULL,
legend_x = NULL,
legend_y = NULL,
legend_width = NULL,
legend_height = NULL,
legend_scale = 1.5,
legend_title_fontsize = 12,
legend_labels_fontsize = 10,
legend_labels_pad = -1.2,
...
)default font size
default font colour
default font family
cell size for core background grobs
number of size categories for core foreground grobs or numeric vector of bin breaks
ratio of minimum to maximum core foreground grobs sizes
color palette for core foreground grobs
bin breaks for color palette for core foreground grobs
'col' or 'row'. Used when recycling fg_params or bg_params to make a matrix of params.
logical, default behaviour for parsing text as plotmath
character vector defining the unit used for sizes. See grid::unit for all possible
specifications.
length-2 vector specifying the horizontal and vertical padding of text within each cell
(optional) set to FALSE to not draw any legend.
(optional) choose between 'top_left', 'top_center' and 'top_right'.
(optional) Only 'columnwise' is supported for now.
(optional) x position in 'npc' units of the left bottom corner of the viewport defining the scale legend. If NULL, the function will try to set it automatically using legend_position.
(optional) y position in 'npc' units of the left bottom corner of the viewport defining the scale legend. If NULL, the function will try to set it automatically.
(optional) width in 'npc' units of the viewport(s) defining legend(s). If NULL, the function will try to set it automatically.
(optional) height in 'npc' units of the viewport(s) defining legend(s). If NULL, the function will try to set it automatically.
(optional) Scale factor that defines the size of the legend colorbar cells relatively to the main plot cells.
(optional) if NULL, font size is set to theme$colhead$fontsize.
(optional) if NULL, font size is set to theme$colhead$fontsize.
(optional) padding between the legend labels.
extra parameters added to the theme list
a list of lists with each sublist defining parameters for the corresponding part of the plot. The parts are
core: defines all graphical parameters for the grobs sizes, shapes and background of the table.
colhead: defines all graphical parameters for the table column labels.
colmore: defines all graphical parameters for the additional column descriptors.
rowhead: defines all graphical parameters for the table row labels.
rowmore: defines all graphical parameters for the additional row descriptors.
legend: defines all graphical parameters for the legend.